==> om-7.x-2.3.tar.gz: om/core/js/om_grids.js <==
// $Id$

/**
 * @file
 * OM Grids Scripts
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */
jQuery(document).ready(function($) {

  var column = getUrlVars()["column"];    
  var screen_center = $(window).width()/2;
  var screen_height = $('body').height();
  
  // when the screen is less then 960, layout will not go negative  
  if(screen_center < 480) {
    screen_center = 480;
  }
  
  // make sure disabled is check on default
  if(column == null) {
    column = 'disabled';
  }
  
  // getting url column value
  function getUrlVars() {
    var vars = {};
    var parts = window.location.href.replace(/[?&]+([^=&]+)=([^&]*)/gi, function(m,key,value) { vars[key] = value; });
    return vars;
  }
  
  // reaction to window resize
  $(window).resize(function() {  
    screen_center = $(window).width()/2;
    screen_height = $('body').height();
    $("#om-grid-guide-12").css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
    $("#om-grid-guide-16").css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
    $("#om-grid-guide-24").css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
  });
  
  // reaction to button change
  $('#om-grid-guide-buttons input').change(function() {
    var button = $(this).val();
    //alert(button);
    if (button != '') {
      $('.om-grid-guide').remove();
      $('body').append('<div id="om-grid-guide-' + button + '" class="om-grid-guide" style="left: ' + (screen_center - 480) + 'px; height: ' + screen_height + 'px"></div>');
      $('#om-grid-guide-' + button).css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
      document.location.href = '?column=' + button;      
    }
    else {
      $('.om-grid-guide').remove();    
      document.location.href = '?column=disabled';
    }      
  }); 
  
  // page refresh
  $('.om-grid-guide').remove();
  $('body').append('<div id="om-grid-guide-' + column + '" class="om-grid-guide" style="left: ' + (screen_center - 480) + 'px; height: ' + screen_height + 'px"></div>');
  $('#om-grid-guide-' + column).css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
  $('#om-grid-guide-button-' + column).attr('checked', 'checked'); 
  
  // button block
  $('#om-grid-guide-buttons').bind('mouseenter', function(){
    $(this).stop(true);  
    $(this).css('left', 0);    
  }).bind('mouseleave', function(){
    $(this).stop(true);
    $(this).animate({left: '-110px'}, 500);      
  });         
});

==> om-7.x-2.5.tar.gz: om/core/js/om_grids.js <==
// $Id$

/**
 * @file
 * OM Grids Scripts
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */
jQuery(document).ready(function($) {

  var column = getUrlVars()["column"]; 
  var overlay = getUrlVars()["overlay"];         
  var screen_center = $(window).width()/2;
  var screen_height = $('body').height();
  
  // when the screen is less then 960, layout will not go negative  
  if(screen_center < 480) {
    screen_center = 480;
  }
  
  // make sure disabled is check on default
  if(column == null) {
    column = 'disabled';
  }

  // make sure disabled is check on default
  if(overlay == null) {
    overlay = 'false';
  }
    
  // getting url column value
  function getUrlVars() {
    var vars = {};
    var parts = window.location.href.replace(/[?&]+([^=&]+)=([^&]*)/gi, function(m,key,value) { vars[key] = value; });
    return vars;
  }
  
  // reaction to window resize
  $(window).resize(function() {  
    screen_center = $(window).width()/2;
    screen_height = $('body').height();
    $("#om-grid-guide-12").css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
    $("#om-grid-guide-16").css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
    $("#om-grid-guide-24").css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
  });
  
  // reaction to button change
  $('#om-grid-guide-buttons input[type=radio]').change(function() {
    var button = $(this).val();
    //alert(button);
    if (button != '') {
      $('.om-grid-guide').remove();
      $('body').append('<div id="om-grid-guide-' + button + '" class="om-grid-guide" style="left: ' + (screen_center - 480) + 'px; height: ' + screen_height + 'px"></div>');
      $('#om-grid-guide-' + button).css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
      document.location.href = '?column=' + button + '&overlay=' + overlay;      
    }
    else {
      $('.om-grid-guide').remove();    
      document.location.href = '?column=disabled&overlay=false';
    }      
  }); 
  
  // page refresh
  $('.om-grid-guide').remove();
  if (column != 'disabled') {
    $('body').append('<div id="om-grid-guide-' + column + '" class="om-grid-guide" style="left: ' + (screen_center - 480) + 'px; height: ' + screen_height + 'px"></div>');
    $('#om-grid-guide-' + column).css('left', (screen_center - 480) + 'px').css('height', screen_height + 'px');
  }
  $('#om-grid-guide-button-' + column).attr('checked', 'checked'); 
  
  // reaction to button change
  $('#om-grid-guide-overlay').click(function() {
		//alert($(this).attr('checked'));  
	  if($(this).attr('checked') == true) {
      $('.om-grid-guide').css('z-index', 1500);
      document.location.href = '?column=' + column + '&overlay=true';
    }
    else {
      $('.om-grid-guide').css('z-index', -1);
      document.location.href = '?column=' + column + '&overlay=false';
    }      
  }); 

  // check button state
	if(overlay == 'true') {
    $('.om-grid-guide').css('z-index', 1500);
    $('#om-grid-guide-overlay').attr('checked', 'checked');
  }
  else {
    $('.om-grid-guide').css('z-index', -1);  
  }
    
  // button block
  $('#om-grid-guide-buttons').bind('mouseenter', function(){
    $(this).stop(true);  
    $(this).css('left', 0);    
  }).bind('mouseleave', function(){
    $(this).stop(true);
    $(this).animate({left: '-110px'}, 500);      
  });         
});
